labelFontWeight property
Optional weight for the button label.
When null, uses the system default weight for the selected style.
Implementation
final FontWeight? labelFontWeight;
Optional weight for the button label.
When null, uses the system default weight for the selected style.
final FontWeight? labelFontWeight;