isSearchTab property

bool isSearchTab
final

Whether this tab is a search tab

Only one tab should be marked as a search tab. When selected, the native iOS 26 search bar will appear with the liquid glass morphing effect.

Implementation

final bool isSearchTab;