CNTabAccessory class

The bottom accessory pill that floats above the tab bar and slides inline into it when the bar minimizes (maps to UITabAccessory).

Constructors

CNTabAccessory({required String text, CNSymbol? sfSymbol})
Creates a bottom accessory pill.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sfSymbol CNSymbol?
Optional leading SF Symbol.
final
text String
The text shown in the accessory pill.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited