disable static method
Dismiss the native tab bar and return to the Flutter app.
Implementation
static Future<void> disable() async {
if (!_enabled) return;
await _channel.invokeMethod('disable');
_reset();
}
Dismiss the native tab bar and return to the Flutter app.
static Future<void> disable() async {
if (!_enabled) return;
await _channel.invokeMethod('disable');
_reset();
}