CNSearchScaffoldItem class

A search scaffold item configuration.

Constructors

CNSearchScaffoldItem({String? label, CNSymbol? icon, CNSymbol? activeIcon, bool isSearchTab = false})
Creates a search scaffold item.
const

Properties

activeIcon CNSymbol?
The SF Symbol for the tab when selected.
final
hashCode int
The hash code for this object.
no setterinherited
icon CNSymbol?
The SF Symbol for the tab (unselected state).
final
isSearchTab bool
Whether this tab is the search tab. Only one tab should be marked as search. This tab will trigger the iOS 26 liquid glass search morphing.
final
label String?
The label for the tab.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited