searchItem property

CNTabBarSearchItem? searchItem
final

Optional search tab configuration.

When provided, adds a dedicated search tab that follows iOS 26's native behavior:

  • Appears as a separate floating circular button on the right
  • Expands into a full search bar when tapped
  • Collapses other tabs during search

On iOS < 26, the search behavior is simulated using Flutter widgets.

Implementation

final CNTabBarSearchItem? searchItem;