didPop method
The Navigator popped route.
The route immediately below that one, and thus the newly active
route, is previousRoute.
Implementation
@override
void didPop(Route<dynamic> route, Route<dynamic>? previousRoute) {
_bumpDown(route);
}
The Navigator popped route.
The route immediately below that one, and thus the newly active
route, is previousRoute.
@override
void didPop(Route<dynamic> route, Route<dynamic>? previousRoute) {
_bumpDown(route);
}