CNButtonDataPopupItem class

Item for a popup menu button in CNGlassButtonGroup.

Constructors

CNButtonDataPopupItem({required String label, String? sfSymbol})
Creates a popup menu item with a label and optional sfSymbol icon.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
The text label displayed in the popup menu.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sfSymbol → String?
Optional SF Symbol name for the menu item icon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited