CNTabAccessory class
The bottom accessory pill that floats above the tab bar and slides inline
into it when the bar minimizes (maps to UITabAccessory).
Constructors
- CNTabAccessory({required String text, CNSymbol? sfSymbol})
-
Creates a bottom accessory pill.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited